bob-query-recipe
================

.. only:: not man

   Name
   ----

   bob-query-recipe - Query package sources

Synopsis
--------

::

    bob query-recipe [-h] [-D DEFINES] [-c CONFIGFILE]
                     [--sandbox | --no-sandbox]
                     package

Description
-----------

Query recipe and class files of package.

Options
-------

``-c CONFIGFILE``
    Use config File

``-D DEFINES``
    Override default environment variable

``--no-sandbox``
    Disable sandboxing

``--sandbox``
    Enable sandboxing
